@@ -1,4 +1,3 @@
-import logging
 import functools
 from pathlib import Path
 import jinja2
@@ -6,15 +5,13 @@ from jinja2 import Environment, FileSystemLoader
 
 from . import config
 
-__version__ = '0.0.2'
+__version__ = '0.0.4'
 
 APP_DIR = Path(__file__).parent
 INPUT_DIR = Path(config.INPUT_PATH)
 CONTENT_DIR = INPUT_DIR / config.CONTENT_DIR_NAME
 OUTPUT_DIR = Path(config.OUTPUT_PATH)
-IGNORE_ASSETS = {'__init__.py', '__pycache__'}
-
-logging.basicConfig(level=config.LOG_LEVEL, format=config.LOG_FORMAT)
+IGNORE_ASSETS = set()
 
 jinja = Environment(
     loader=FileSystemLoader('input/templates', followlinks=True),
